@@ -2,6 +2,7 @@
 
 import logging
 from concurrent.futures import ProcessPoolExecutor
+from pathlib import Path
 from typing import List
 
 from pylama.config import Namespace
@@ -27,13 +28,15 @@ def worker(params):
 
 
 def check_async(
-    paths: List[str], code: str = None, options: Namespace = None, rootdir: str = None
+    paths: List[str], code: str = None, options: Namespace = None, rootdir: Path = None
 ) -> List[Error]:
     """Check given paths asynchronously."""
     with ProcessPoolExecutor(CPU_COUNT) as pool:
         return [
             err
-            for res in pool.map(worker, [(path, code, options, rootdir) for path in paths])
+            for res in pool.map(
+                worker, [(path, code, options, rootdir) for path in paths]
+            )
             for err in res
         ]
 
