@@ -4,13 +4,13 @@ from __future__ import absolute_import
 
 import sys
 from configparser import ConfigParser  # noqa
-from os import chmod
+from os import chmod, getcwd
 from os import path as op
 from subprocess import PIPE, Popen
 from typing import List, Tuple
 
-from .config import parse_options, setup_logger
-from .main import LOGGER, check_paths, display_errors
+from pylama.config import parse_options, setup_logger
+from pylama.main import LOGGER, check_paths, display_errors
 
 
 def run(command: str) -> Tuple[int, List[bytes], List[bytes]]:
@@ -32,7 +32,7 @@ def git_hook(error=True):
     setup_logger(options)
     candidates = [f.decode("utf-8") for f in files_modified]
     if candidates:
-        errors = check_paths(candidates, options)
+        errors = check_paths(candidates, options, rootdir=getcwd())
         display_errors(errors, options)
         sys.exit(int(error and bool(errors)))
 
@@ -61,7 +61,7 @@ def hg_hook(_, repo, node=None, **kwargs):  # noqa
 def install_git(path):
     """Install hook in Git repository."""
     hook = op.join(path, "pre-commit")
-    with open(hook, "w", encoding='utf-8') as target:
+    with open(hook, "w", encoding="utf-8") as target:
         target.write(
             """#!/usr/bin/env python
 import sys
@@ -78,10 +78,10 @@ def install_hg(path):
     """Install hook in Mercurial repository."""
     hook = op.join(path, "hgrc")
     if not op.isfile(hook):
-        open(hook, "w+", encoding='utf-8').close()
+        open(hook, "w+", encoding="utf-8").close()
 
     cfgp = ConfigParser()
-    with open(hook, "r", encoding='utf-8') as source:
+    with open(hook, "r", encoding="utf-8") as source:
         cfgp.read_file(source)
 
     if not cfgp.has_section("hooks"):
@@ -93,7 +93,7 @@ def install_hg(path):
     if not cfgp.has_option("hooks", "qrefresh"):
         cfgp.set("hooks", "qrefresh", "python:pylama.hooks.hg_hook")
 
-    with open(hook, "w+", encoding='utf-8') as target:
+    with open(hook, "w+", encoding="utf-8") as target:
         cfgp.write(target)
 
 
